@@ -1,13 +1,13 @@
 # function to display estimation results  2015-3-11 Thong Pham
 print.PAFit_result <- function(x,...) {
-  cat("\nPAFit_result object contains the estimation results by the PAFit method. \n")
+  cat("\nContaining the estimation results by the PAFit method. \n")
   if (x$only_PA == TRUE) {
-      cat("Mode: Only the PA function was estimated. \n")     
+      cat("Mode: Only the attachment function was estimated. \n")     
   } else if (x$only_f == TRUE) {
       cat("Mode: Only node fitnesses were estimated. \n")
   }
   else {
-      cat("Mode: Both the attachment kernel and node fitness were estimated. \n")
+      cat("Mode: Both the attachment function and node fitness were estimated. \n")
   }
   
   #cat(" Form of the PA function:",x$mode_f,"\n");
