@@ -5,7 +5,7 @@ summary.PAFit_data <- function(object,...){
   cat("Number of edges in the final network: ",sum(object$final_deg),"\n")
   cat("Number of new nodes: ",length(object$final_deg) - object$initial_nodes,"\n")
   cat("Number of new edges: ",sum(object$sum_m_k), "\n")
-  cat("Numbef of time-steps:",  object$T,"\n");
+  cat("Number of time-steps:",  object$T,"\n");
   cat("Maximum degree: ", object$deg_max,"\n");
   cat("Number of bins:", object$g,"\n");
 }
\ No newline at end of file
