@@ -1,3 +1,5 @@
+
+
 if (FALSE) {
   #setwd("tests")
   rm(list = ls())
@@ -15,27 +17,24 @@ if (FALSE) {
   r_optimal     <- rep(0,M)
   for (i in 1:M) {
       #set.seed(1)
-      net  <- Generate_BB(N = 1000, m = 15, num_seed = 100, 
-                          multiple_node = 100,
+      net  <- generate_BB(N = 1000, m = 15, num_seed = 200, 
+                          multiple_node = 200,
                           s = 1) 
                           #shape = 1, rate = 1)
   
-      net_stats <- GetStatistics(net$graph) 
+      net_stats <- get_statistics(net) 
   
-      print(system.time(result <- JointEstimate(net$graph, 
-                                                net_stats)))
+      print(result <- joint_estimate(net, net_stats))
       
-      result
-      
-      
-                        
+      #result
+                      
       alpha_vec[i]     <- result$estimate_result$alpha
       s_vec[i]         <- result$estimate_result$shape
       alpha_optimal[i] <- result$cv_result$alpha_optimal
       r_optimal[i]     <- result$cv_result$r_optimal
   }
   print(alpha_vec)  
-  mean(alpha_vec)
+  print(mean(alpha_vec))
   print(s_vec)
-  mean(s_vec)
+  print(mean(s_vec))
 }
